summaryrefslogtreecommitdiff
path: root/rts/sm/CNF.c
diff options
context:
space:
mode:
Diffstat (limited to 'rts/sm/CNF.c')
-rw-r--r--rts/sm/CNF.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/rts/sm/CNF.c b/rts/sm/CNF.c
index 7dfaced7ef..624dba30b2 100644
--- a/rts/sm/CNF.c
+++ b/rts/sm/CNF.c
@@ -176,8 +176,8 @@ compactAllocateBlockInternal(Capability *cap,
n_blocks >= HS_INT32_MAX) // avoid overflow when
// calling allocGroup() below
{
- heapOverflow();
- // heapOverflow() doesn't exit (see #2592), but we aren't
+ reportHeapOverflow();
+ // reportHeapOverflow() doesn't exit (see #2592), but we aren't
// in a position to do a clean shutdown here: we
// either have to allocate the memory or exit now.
// Allocating the memory would be bad, because the user